/// <reference types="node" />
import { Writable } from 'stream';
import { EventEmitter } from 'events';
import { IncomingHttpHeaders } from 'http';
import { StringDecoder } from 'string_decoder';
import createError = require('http-errors');
import { FormOptions, Fn, HoldEmitQueueItem, PassThroughExt, OpenedFile, NodeReq } from './types';
export declare class Form extends Writable {
    /**
     * The amount of bytes received for this form so far.
     */
    bytesReceived: number;
    /**
     * The expected number of bytes in this form.
     */
    bytesExpected: number;
    protected error: Error;
    protected autoFields: boolean;
    protected autoFiles: boolean;
    protected maxFields: number;
    protected maxFieldsSize: number;
    protected maxFilesSize: number;
    protected uploadDir: string;
    protected encoding: BufferEncoding;
    protected openedFiles: OpenedFile[];
    protected totalFieldSize: number;
    protected totalFieldCount: number;
    protected totalFileSize: number;
    protected flushing: number;
    protected backpressure: boolean;
    protected writeCbs: Fn[];
    protected emitQueue: HoldEmitQueueItem[];
    protected destStream: PassThroughExt;
    protected req: NodeReq;
    protected waitend: boolean;
    protected boundOnReqAborted: Fn;
    protected boundOnReqEnd: Fn;
    protected partTransferEncoding: string;
    protected partHeaders: IncomingHttpHeaders;
    protected headerFieldDecoder: StringDecoder;
    protected headerValueDecoder: StringDecoder;
    protected headerField: string;
    protected headerValue: string;
    protected partFilename: string;
    protected partName: string;
    protected boundary: Buffer;
    protected index: number;
    protected partDataMark: number;
    protected headerValueMark: number;
    protected headerFieldMark: number;
    protected partBoundaryFlag: boolean;
    protected state: number;
    protected lookbehind: Buffer;
    protected boundaryChars: {
        [x: string]: boolean;
    };
    constructor(options?: FormOptions);
    parse(req: NodeReq, cb: Fn): void;
    _write(buffer: Buffer, encoding: string, cb: Fn): void;
    onParsePartBegin(): void;
    onParseHeaderField(b: Buffer): void;
    onParseHeaderValue(b: Buffer): void;
    onParseHeaderEnd(): void;
    onParsePartData(b: Buffer): void;
    onParsePartEnd(): void;
    onParseHeadersEnd(offset: number): createError.HttpError;
    protected onReqEnd(): void;
    protected handleError(err: Error): void;
    protected onReqAborted(): void;
    protected clearPartVars(): void;
    protected parseFilename(headerValue: string): string;
    protected lower(c: number): number;
    protected flushWriteCbs(): void;
    protected getBytesExpected(headers: IncomingHttpHeaders): number;
    protected beginFlush(): void;
    protected endFlush(): void;
    protected cleanupOpenFiles(): void;
    protected holdEmitQueue(eventEmitter?: EventEmitter): (cb: Fn) => void;
    protected errorEventQueue(eventEmitter: EventEmitter, err: Error): void;
    protected handlePart(partStream: PassThroughExt): void;
    protected handleFile(fileStream: PassThroughExt): void;
    protected handleField(fieldStream: PassThroughExt): void;
    protected setUpParser(boundary: string): void;
}
